/*
 * Copyright 2011-2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
 
[CCode(cname="g_type_is_a", cheader_filename = "glib.h")]
extern bool g_type_is_a(Type t1, Type t2);

bool check_type<T>(Object? object){
	return object != null && g_type_is_a(object.get_type(), typeof(T));
}
 /**
 * Object Container maps object name to object instance. It is used to
 * provide dependencies for extensions.
 */
public class Nuvola.ObjectContainer{
	private HashTable<string, Object?> objects;
	
	/**
	 * Creates new ObjectContainer.
	 * @param objects	hastable with available objects
	 */
	public ObjectContainer(HashTable<string, Object?> objects){
		this.objects = objects;
	}
	
	
	/**
	 * Returns object with given name and type.
	 * 
	 * @param id				name of the object
	 * @return					object instance
	 * @throws ExtensionError	when object is not fond or has different type
	 */
	public unowned T get<T>(string id) throws ExtensionError{
		weak Object? object = objects.lookup(id);
		if(check_type<T>(object)){
			return (T) object;
		}
		else{
			throw new ExtensionError.OBJECT_NOT_FOUND(@"Object '$id' not found.");
		}
	}
}
