/*
 * Copyright 2011-2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * PopupView displays content of pages opened by JavaScript function
 * window.open(). These pages are opened in new window.
 */
public class Nuvola.PopupWebView : Nuvola.WebView{
	private Gtk.Dialog dialog;
	/**
	 * Creates new PopupView.
	 * 
	 * @param settings settings for WebView
	 */
	public PopupWebView(WebKit.WebSettings settings){
		base();
		this.set_settings(get_settings());
		this.show();
	}
	
	#if DEBUG_MEMORY
	~PopupWebView(){
		debug("PopupView destroyed");
	}
	#endif
	
	public override bool web_view_ready(){
		/* It's time to create new window and show the view */
		this.dialog = new Gtk.Dialog(); 
		var sw = new Gtk.ScrolledWindow(null, null);
		(dialog.get_content_area() as Gtk.Container).add(sw);
		sw.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC);
		sw.add(this);
		// Allow expansion, otherwise page area is tiny and rest of the window is empty. LP:1181950
		sw.expand = true;
		this.dialog.title = " ";
		this.title_changed.connect((source, frame, title) => {
			this.dialog.title = title;
		});
		this.dialog.set_default_size(600, 400);
		this.dialog.show_all();
		return true;
	}
	
	public override bool close_web_view(){
		/* Destroy dialog and view */
		if(this.dialog != null){
			this.dialog.destroy();
			this.dialog = null;
		}
		this.destroy();
		return true;
	}
}
