/*
 * Copyright 2014 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
Gtk.Entry entry;

int main(string[] args)
{
	Gtk.init(ref args);
	
	entry = new Gtk.Entry();
	var view = new WebKit.WebView();
	
	entry.margin = 5;
	entry.vexpand = false;
	entry.hexpand = true;
	entry.activate.connect(() =>
	{
		view.load_uri(entry.text);
	});
	entry.show();
	
	view.notify["uri"].connect_after((o, p) =>
	{
		entry.text = view.uri;
	});
	view.show();
	
	var scroll = new Gtk.ScrolledWindow(null, null);
	scroll.expand = true;
	scroll.add(view);
	scroll.show();
	
	var button = new Gtk.Button.with_label("Go");
	button.clicked.connect(() =>
	{
		view.load_uri(entry.text);
	});
	button.margin = 5;
	button.expand = false;
	button.show();
	
	var grid = new Gtk.Grid();
	grid.attach(entry, 0, 0, 1, 1);
	grid.attach(button, 1, 0, 1, 1);
	grid.attach(scroll, 0, 1, 2, 1);
	grid.show();
	
	var win = new Gtk.Window();
	win.title = "WebKitGtk-3.0 %u.%u.%u".printf(WebKit.major_version(), WebKit.minor_version(), WebKit.micro_version());
	win.set_default_size(800, 600);
	win.add(grid);
	win.delete_event.connect(() => {Gtk.main_quit(); return true;});
	win.present();
	
	if (args.length > 1)
	{
		entry.text = args[1];
		view.load_uri(args[1]);
	}
	else
	{
		entry.text = "http://";
	}
	entry.move_cursor(Gtk.MovementStep.BUFFER_ENDS, 1, false);
	Gtk.main();
	
	return 0;
}
